@@ -7,7 +7,7 @@ from typing import Optional, Tuple
 
 from glyphsLib.builder import UFOBuilder
 import yaml
-from fontTools.designspaceLib import DesignSpaceDocument, InstanceDescriptor
+from fontTools.designspaceLib import InstanceDescriptor
 from strictyaml import load, YAMLValidationError
 
 from gftools.builder.file import File
@@ -15,6 +15,7 @@ from gftools.builder.recipeproviders import RecipeProviderBase
 from gftools.builder.schema import (
     GOOGLEFONTS_SCHEMA,
     stat_schema,
+    avar2_schema,
     stat_schema_by_font_name,
 )
 from gftools.utils import open_ufo
@@ -98,6 +99,17 @@ class GFBuilder(RecipeProviderBase):
             yaml.dump(self.config["stat"], self.statfile)
         else:
             self.statfile = None
+
+        if "avar2" in self.config:
+            self.avar2file = NamedTemporaryFile(delete=False, mode="w+")
+            load(yaml.dump(self.config["avar2"]), avar2_schema)
+            for font in list(self.config["avar2"].keys()):
+                scfont = re.sub(r"((?:-Italic)?\[)", r"SC\1", font)
+                self.config["avar2"][scfont] = self.config["avar2"][font]
+            yaml.dump(self.config["avar2"], self.avar2file)
+        else:
+            self.avar2file = None
+
         # Find variable fonts
         self.recipe = {}
         self.build_all_variables()
@@ -198,7 +210,7 @@ class GFBuilder(RecipeProviderBase):
         if self.config.get("extraFontmakeArgs") is not None:
             args += " " + str(self.config["extraFontmakeArgs"])
         if variable:
-            if self.config.get("checkCompatibility") == False:
+            if self.config.get("checkCompatibility") is False:
                 args += " --no-check-compatibility"
             if self.config.get("extraVariableFontmakeArgs") is not None:
                 args += " " + str(self.config["extraVariableFontmakeArgs"])
@@ -218,7 +230,12 @@ class GFBuilder(RecipeProviderBase):
         if self.config.get("fvarInstanceAxisDflts"):
             args += (
                 " --fvar-instance-axis-dflts '"
-                + self.config["fvarInstanceAxisDflts"]
+                + " ".join(
+                    [
+                        f"{k}={v}"
+                        for k, v in self.config["fvarInstanceAxisDflts"].items()
+                    ]
+                )
                 + "'"
             )
         return args
@@ -227,11 +244,7 @@ class GFBuilder(RecipeProviderBase):
         if not self.config.get("buildVariable", True):
             return
         for source in self.sources:
-            if (
-                (source.is_glyphs and len(source.gsfont.masters) < 2)
-                or source.is_ufo
-                or (source.is_designspace and len(source.designspace.sources) < 2)
-            ):
+            if not source.is_variable:
                 continue
             italic_ds = None
             if self.config["splitItalic"]:
@@ -244,6 +257,8 @@ class GFBuilder(RecipeProviderBase):
             else:
                 self.build_a_variable(source)
         self.build_STAT()
+        if "avar2" in self.config:
+            self.build_avar2()
 
     def build_STAT(self):
         # Add buildStat to a variable target, it'll do for all of them
@@ -267,6 +282,14 @@ class GFBuilder(RecipeProviderBase):
                 build_stat_step["needs"] = other_variables
             self.recipe[last_target].append(build_stat_step)
 
+    def build_avar2(self):
+        vfs = [x for x in self.recipe.keys() if x.endswith("ttf")]
+        if len(vfs) > 0:
+            args = {"args": self.avar2file.name, "postprocess": "buildAvar2"}
+            for vf in vfs:
+                self.recipe[vf].append(args)
+            self.avar2file.close()
+
     def _vtt_steps(self, target: str):
         if os.path.basename(target) in self.config.get("vttSources", {}):
             return [
@@ -280,17 +303,26 @@ class GFBuilder(RecipeProviderBase):
     def build_a_variable(
         self, source: File, italic_ds: Italic = None, roman: bool = False
     ):
+        suffix = self.config.get("filenameSuffix", "")
         if roman:
-            target = self._vf_filename(source, italic_ds=italic_ds, roman=True)
+            target = self._vf_filename(
+                source, suffix=suffix, italic_ds=italic_ds, roman=True
+            )
         else:
-            target = self._vf_filename(source, italic_ds=italic_ds, roman=False)
-        steps = [
-            {"source": source.path},
-            {
-                "operation": "buildVariable",
-                "args": self.fontmake_args(source, variable=True),
-            },
-        ] + self._vtt_steps(target)
+            target = self._vf_filename(
+                source, suffix=suffix, italic_ds=italic_ds, roman=False
+            )
+        steps = (
+            [
+                {"source": source.path},
+                {
+                    "operation": "buildVariable",
+                    "args": self.fontmake_args(source, variable=True),
+                },
+            ]
+            + self.config.get("postCompile", [])
+            + self._vtt_steps(target)
+        )
         if italic_ds:
             desired_slice = italic_ds[0] + "="
             if roman:
@@ -322,12 +354,14 @@ class GFBuilder(RecipeProviderBase):
                     self.build_a_static(source, instance, output="otf")
 
     def build_a_static(self, source: File, instance: InstanceDescriptor, output):
-        target = self._static_filename(instance, extension=output)
+        suffix = self.config.get("filenameSuffix", "")
+        target = self._static_filename(instance, suffix=suffix, extension=output)
 
         steps = [
             {"source": source.path},
         ]
-        if not source.is_ufo:
+        # if we're running fontc we skip conversion to UFO
+        if not source.is_ufo and not self.config.get("use_fontc", False):
             instancename = instance.name
             if instancename is None:
                 if not instance.familyName or not instance.styleName:
@@ -349,6 +383,7 @@ class GFBuilder(RecipeProviderBase):
                     "args": self.fontmake_args(source, variable=False),
                 }
             ]
+            + self.config.get("postCompile", [])
             + self._autohint_steps(target)
             + self._vtt_steps(target)
             + self._fix_step()
