@@ -82,15 +82,28 @@ subsets: "menu"
 PR_CHECKLIST = """
 ## PR Checklist:
 
-- [ ] `minisite_url` definition in the METADATA.pb file for commissioned projects
-- [ ] `primary_script` definition in the METADATA.pb file for all projects that have a primary non-Latin based language support target
-- [ ] `subsets` definitions in the METADATA.pb reflect the actual subsets and languages present in the font files (in alphabetic order). For **CJK fonts**, only include one of the following subsets `chinese-hongkong`, `chinese-simplified`, `chinese-traditional`, `korean`, `japanese`.
+### PR
+- [ ] The PR is in the Traffic Jam Board (Project > Traffic Jam Board)
+- [ ] It has the correct labels (upgrade, new font, specific language)
+- [ ] The PR is linked to the corresponding issue
+
+### QA
 - [ ] Fontbakery checks are reviewed and failing checks are resolved in collaboration with the upstream font development team
 - [ ] Diffenator2 regression checks for revisions on all projects that are currently in production
+- [ ] The article has no typos, images are properly linked and correctly sized
+- [ ] OFL.txt contains the correct license URL (https://openfontlicense.org)
+
+### Specifics
+- [ ] `primary_script` definition in the METADATA.pb file for all projects that have a primary non-Latin based language support target
+- [ ] `subsets` definitions in the METADATA.pb reflect the actual subsets and languages present in the font files (in alphabetic order). For **CJK fonts**, only include one of the following subsets `chinese-hongkong`, `chinese-simplified`, `chinese-traditional`, `korean`, `japanese`.
+
+### Release
 - [ ] Designers bio info have to be present in the designer catalog (at least an issue should be opened for tracking this, if they are not)
 - [ ] Check designers order in metadata.pb, since the first one of the list appears as “principal designer”
 - [ ] Social media formatted visual assets for all new commissioned projects in the Drive directory, communicate with the repository Maintainer so that they can push this content to the Social Media tracker spreadsheet
 - [ ] Social media content draft for all new commissioned projects in the Drive directory and Social Media tracker spreadsheet, communicate with the repository Maintainer so that they can push this content to the Social Media tracker spreadsheet
+- [ ] `minisite_url` definition in the METADATA.pb file for commissioned projects
+- [ ] `tags` are added for NEW FONTS
 """
 
 
@@ -422,7 +435,7 @@ def git_tree_traverse(func, *args, **kwargs):
         tree = repo.get(tree_oid)
         try:
             entry = tree[subtree_name]
-            existing_subtree = repo.get(entry.hex)
+            existing_subtree = repo.get(entry.id)
             sub_treebuilder = repo.TreeBuilder(existing_subtree)
         except KeyError:
             sub_treebuilder = repo.TreeBuilder()
@@ -514,7 +527,14 @@ def push_family(family_path: Path, branch_name: str, head_repo: str):
     if is_ssh:
         repo_url = f"git@github.com:{head_repo}/fonts.git"
     else:
-        repo_url = f"https://github.com/{head_repo}/fonts.git"
+        username = os.environ.get("GH_USERNAME")
+        gh_token = os.environ.get("GH_TOKEN")
+        if not username or not gh_token:
+            raise ValueError(
+                "GH_USERNAME and GH_TOKEN environment variables are required to push "
+                "to the repo."
+            )
+        repo_url = f"https://{username}:{gh_token}@github.com/{head_repo}/fonts.git"
     subprocess.run(
         [
             "git",
@@ -557,6 +577,7 @@ def pr_family(
             google_fonts.add_labels(open_prs[0]["number"], ["I New Font"])
     else:
         resp = google_fonts.create_issue_comment(open_prs[0]["number"], "Updated")
+        google_fonts.update_pr(open_prs[0]["number"], title=title)
         log.info(f"Updated PR '{resp['html_url']}'")
 
     # inherit labels from issue
@@ -566,7 +587,7 @@ def pr_family(
             open_prs[0]["number"], [l["name"] for l in issue_labels]
         )
     # add item to traffic board
-    if TRAFFIC_JAM_ID:
+    if TRAFFIC_JAM_ID and not open_prs:
         log.info(f"Adding project to traffic jam")
         google_fonts._run_graphql(
             ADD_TO_TRAFFIC_JAM.format(
